package teethferries.persistence;

import java.io.*;
import java.text.NumberFormat;
import java.text.ParseException;
import java.time.LocalTime;
import java.time.format.DateTimeParseException;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

import teethferries.model.*;

public class MyServiziReader implements ServiziReader
{
	@Override
	public List<Servizio> leggiServizi(Reader reader, List<Tratta> tratte) throws IOException,
			MalformedFileException
	{
		ArrayList<Servizio> servizi = new ArrayList<Servizio>();
		BufferedReader servicesReader = new BufferedReader(reader);
		Map<String, Tratta> tratteMap = tratte.stream()
				.collect(Collectors.toMap(Tratta::getId, Function.identity()));
		try
		{
			String line;
			while ((line = servicesReader.readLine()) != null)
			{
				StringTokenizer tokenizer = new StringTokenizer(line, ";");	
				
				String trattaId = tokenizer.nextToken();
				Tratta tratta = tratteMap.get(trattaId);
				if (tratta == null)
					throw new MalformedFileException("Tratta non trovata: " + trattaId);
				
				LocalTime partenza = LocalTime.parse(tokenizer.nextToken());
				LocalTime arrivo = LocalTime.parse(tokenizer.nextToken());
				String nave = tokenizer.nextToken();
				NumberFormat formatter = NumberFormat.getCurrencyInstance();
				double costo = formatter.parse(tokenizer.nextToken()).doubleValue();				
				Servizio servizio = new Servizio(nave, tratta, partenza, arrivo, costo);
				servizi.add(servizio);
			}
		}
		catch (NoSuchElementException | ParseException | DateTimeParseException e)
		{
			throw new MalformedFileException(e);
		}
		return servizi;
	}
}
